@@ -17,7 +17,7 @@ use Class::Accessor::Lite (
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 sub load {
     my $v = Data::Validator->new(
@@ -62,7 +62,9 @@ sub create {
 
 sub create_all {
     my ($self,) = @_;
-    $self->create([$self->dbh->tables]);
+
+    my @tables = map { $_->[2] } @{$self->dbh->table_info('','','')->fetchall_arrayref};
+    $self->create(\@tables);
 }
 
 sub ignore_tables {
@@ -135,7 +137,7 @@ sub _build_create_data {
         tables => +{ isa => 'ArrayRef[Str]' }
     )->with(qw/Method StrictSequenced/);
     my($self, $args) = $v->validate(@_);
-    my @tables = difference($args->{tables}, [$self->ignore_tables]);
+    my @tables = $self->_difference_ignore_tables($args->{tables});
     return unless scalar @tables;
 
     my $schema = Teng::Schema::Loader->load(
